import 'package:flutter/material.dart';
import 'package:i18n_plus/i18nLanguageset.dart';

class I18NMap {
  ///[Locale] determines the [language] of the set
  ///The Keys of a [languageset] must be consistent throughout all sets
  ///and therefore existent in all sets
  List<Langaugeset> languageSets;

  ///bool [valid] is used to indicate if the language sets are valid.
  ///For the language sets to be valid, the same keys have to be present
  ///in every language set
  bool valid;

  I18NMap(List<Langaugeset> languageSets) {
    this.languageSets = languageSets;
    this.valid = _checkIfValid();
  }

  ///Returns [Langaugeset] with matching [Locale]
  ///Will throw BadState error is [Locale] cannot be found
  Langaugeset getWithLocale(Locale locale) {
    return languageSets.where((element) => element.locale == locale).first;
  }

  ///Checks if [Keys] of every [language set] can be found in eachother
  bool _checkIfValid() {
    if (this.languageSets.length >= 0) {
      List<Locale> _locale = [];
      for (Locale locale
          in languageSets.map((langaugeset) => langaugeset.locale).toList()) {
        if (!_locale.contains(locale)) {
          _locale.add(locale);
        } else {
          throw ("Invalid i18nMap: Multiple Languagesets with identical Locale ${locale.toLanguageTag()}");
        }
      }
      List<Map> _languageSets =
          languageSets.map((langaugeset) => langaugeset.map).toList();
      List _keys = _languageSets[0].keys.toList();
      for (Map languageSet in _languageSets) {
        List _currentKeys = languageSet.keys.toList();
        for (int x = 0; x < _keys.length; x++) {
          if (!_keys.contains(_currentKeys[x])) {
            return false;
          }
        }
        _keys = languageSet.keys.toList();
      }
      return true;
    } else {
      return false;
    }
  }
}
