import 'dart:core';
import 'package:flutter/cupertino.dart';
import 'package:i18n_plus/i18n.dart';

///[i18nKey] must be a valid key in your current i18nMap
///[additionalString] can be added to your i18n value. If not null
///[otherLocale] fill field if you do not want to use the current locale
///All other params are the same as in the original [Text] widget
class I18NText extends StatefulWidget {
  final String i18nKey;
  final String additionalString;
  final Locale otherLocale;
  final TextStyle style;
  final StrutStyle strutStyle;
  final TextAlign textAlign;
  final TextDirection textDirection;
  final bool softWrap;
  final TextOverflow overflow;
  final double textScaleFactor;
  final int maxLines;
  final String semanticsLabel;
  final TextWidthBasis textWidthBasis;
  final TextHeightBehavior textHeightBehavior;

  const I18NText(
      {Key key,
      this.i18nKey,
      this.style,
      this.strutStyle,
      this.textAlign,
      this.textDirection,
      this.softWrap,
      this.overflow,
      this.textScaleFactor,
      this.maxLines,
      this.semanticsLabel,
      this.textWidthBasis,
      this.textHeightBehavior,
      this.otherLocale,
      this.additionalString})
      : super(key: key);
  @override
  I18NTextState createState() => I18NTextState();
}

class I18NTextState extends State<I18NText> {
  String _i18nKey;
  String _addtionalString;
  Locale _otherLocale;
  TextStyle _style;
  StrutStyle _strutStyle;
  TextAlign _textAlign;
  TextDirection _textDirection;
  bool _softWrap;
  TextOverflow _overflow;
  double _textScaleFactor;
  int _maxLines;
  String _semanticsLabel;
  TextWidthBasis _textWidthBasis;
  TextHeightBehavior _textHeightBehavior;
  final I18N _i18n = I18N();

  @override
  void initState() {
    super.initState();
    _i18nKey = widget.i18nKey;
    _addtionalString = widget.additionalString;
    _otherLocale = widget.otherLocale;
    _style = widget.style;
    _strutStyle = widget.strutStyle;
    _textAlign = widget.textAlign;
    _textDirection = widget.textDirection;
    _softWrap = widget.softWrap;
    _overflow = widget.overflow;
    _textScaleFactor = widget.textScaleFactor;
    _maxLines = widget.maxLines;
    _semanticsLabel = widget.semanticsLabel;
    _textWidthBasis = widget.textWidthBasis;
    _textHeightBehavior = widget.textHeightBehavior;
  }

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
        valueListenable: _i18n.currentLocale,
        builder: (BuildContext context, Locale value, Widget child) {
          return Text(_textString(_i18nKey, _addtionalString, _otherLocale),
              textAlign: _textAlign,
              style: _style,
              strutStyle: _strutStyle,
              textDirection: _textDirection,
              softWrap: _softWrap,
              overflow: _overflow,
              textScaleFactor: _textScaleFactor,
              maxLines: _maxLines,
              semanticsLabel: _semanticsLabel,
              textWidthBasis: _textWidthBasis,
              textHeightBehavior: _textHeightBehavior);
        },
        child: null);
  }

  String _textString(String key, String add, Locale otherLocale) {
    add = add != null ? add : "";
    if (_otherLocale != null && _i18n.allLocale().contains(_otherLocale)) {
      if (_i18n.i18nMap.getWithLocale(otherLocale).map[key] != null) {
        return _i18n.i18nMap.getWithLocale(otherLocale).map[key] + add;
      } else {
        return "Invalid Key";
      }
    } else if (_otherLocale == null) {
      if (_i18n.i18nMap.getWithLocale(_i18n.currentLocale.value).map[key] !=
          null) {
        return _i18n.i18nMap.getWithLocale(_i18n.currentLocale.value).map[key] +
            add;
      } else {
        return "Invalid Key";
      }
    }
    return "Invalid Locale";
  }
}
